==> fwbuilder_1.0.0.orig.tar.gz: fwbuilder-1.0.0.orig/src/gui/post-glade.pl <==
#!/usr/bin/perl
#
#
#
#  $Revision: 1.10 $
# 
#  $Id: post-glade.pl,v 1.10 2001/12/22 02:34:35 vkurland Exp $
#
#
# 

@files=`ls *_glade.hh *_glade.cc 2>/dev/null`;

if ( @files == 0 ) {
#    print "No files\n";
    exit(0);
}

@files=`egrep -li '^class .* : public Gtk::Window' *Dialog_glade.hh | egrep -v 'InterfaceDialog|MessageDialog|RuleOptionsDialog|MiniBrowserDialog|FilterDialog|FindDialog|AboutDialog|SimpleProgressDialog|WhereUsedDialog'`;

foreach $f ( @files ) {

    chop($f);

    $c = $f;
    $c =~ s/\.hh/.cc/;

    print "'$f'  '$c'\n";

    $old_sep=$/;
    $/='\0xFF';
    open F, "$f" || die "Can not open file $f";
    $hf=<F>;
    close F;

    $hf=~ s/class\s+(\S+)\s+:\s+public\s+Gtk::Window/#include \"DialogPlugin.hh\"\n\nclass \1 : public DialogPlugin/;
    $hf=~ s/\s+(Gtk::Window)\s+\*/\n\n\tDialogPlugin \*/;
    $hf=~ s/\&quot;/'/g;    #'

    open F, ">$f" || die "Can not open file $f for writing";
    print F $hf;
    close F;

    open F, "$c" || die "Can not open file $c";
    $cf=<F>;
    close F;

    $cf=~ s/: Gtk::Window\(GTK_WINDOW_TOPLEVEL\)//;
    $cf=~ s/Gtk::Window \*/DialogPlugin */;

    open F,">$c" || die "Can not open file $c for writing";
    print F $cf;
    close F;

    $/=$old_sep;
}

undef @files;
undef $f;

@files=`egrep -li '^.+const char \\* const \\(items\\[\\]\\)' *Dialog_glade.cc`;

foreach $f ( @files ) {

    chop($f);

    print "'$f'\n";

    $old_sep=$/;
    $/='\0xFF';
    open F, "$f" || die "Can not open file $f";
    $hf=<F>;
    close F;

    $hf=~ s/\s+const char \* const \(items/const char * \(items/g;

    open F, ">$f" || die "Can not open file $f for writing";
    print F $hf;
    close F;

}



# @files=`ls *_glade.cc *_glade.hh`;
#
#foreach $f ( @files ) {
#    chop($f);
#    `diff -q -N -I\"^// generated\" -I\"^// glade--.*\.glade$\"  .. $f >/dev/null 2>1`;
#    $res=$?;
#    if ($res!=0) {
#	`cp $f ..`
#    }
#}


`touch postglade.timestamp`

==> fwbuilder_1.1.2.orig.tar.gz: fwbuilder-1.1.2/src/gui/post-glade.pl <==
#!/usr/bin/perl
#
#
#
#  $Revision: 1.19 $
# 
#  $Id: post-glade.pl,v 1.19 2002/08/24 18:39:06 vkurland Exp $
#
#
# 

@files=`ls *_glade.hh *_glade.cc 2>/dev/null`;

if ( @files == 0 ) {
#    print "No files\n";
    exit(0);
}

@files=`egrep -li '^class .* : public Gtk::Window' *Dialog*_glade.hh | egrep -v 'MessageDialog|RuleOptionsDialog|MiniBrowserDialog|FilterDialog|FindDialog|AboutDialog|SimpleProgressDialog|SimplePasswordDialog|SimpleTextDialog|WhereUsedDialog|GenericBackgroundOpDialog|PIXAdvancedFWDialog|PIXAdvancedNetDialog'`;

foreach $f ( @files ) {

    chop($f);

    $c = $f;
    $c =~ s/\.hh/.cc/;

    print " 1 '$f'  '$c'\n";

    $old_sep=$/;
    $/='\0xFF';
    open F, "$f" || die "Can not open file $f";
    $hf=<F>;
    close F;

    $hf=~ s/class\s+(\S+)\s+:\s+public\s+Gtk::Window/#include \"DialogPlugin.hh\"\n\nclass \1 : public DialogPlugin/;
    $hf=~ s/\s+(Gtk::Window)\s+\*/\n\n\tDialogPlugin \*/;
    $hf=~ s/\&quot;/'/g;    #'

    open F, ">$f" || die "Can not open file $f for writing";
    print F $hf;
    close F;

    open F, "$c" || die "Can not open file $c";
    $cf=<F>;
    close F;

    $cf=~ s/: Gtk::Window\(GTK_WINDOW_TOPLEVEL\)//;
    $cf=~ s/Gtk::Window \*/DialogPlugin */;

    open F,">$c" || die "Can not open file $c for writing";
    print F $cf;
    close F;

    $/=$old_sep;
}

undef @files;
undef $f;

@files=`egrep -li '^.+const char \\* const items\\[\\]' *Dialog_glade.cc`;

foreach $f ( @files ) {

    chop($f);

    print " 2 '$f'\n";

    $old_sep=$/;
    $/='\0xFF';
    open F, "$f" || die "Can not open file $f";
    $hf=<F>;
    close F;

    $hf=~ s/\s+const char \* const items/const char * items/g;

    open F, ">$f" || die "Can not open file $f for writing";
    print F $hf;
    close F;

    $/=$old_sep;
}


undef @files;
undef $f;

@files=`egrep -li '#include <libgnome' *_glade.cc`;

foreach $f ( @files ) {

    chop($f);

    print " 3 '$f'\n";

    $old_sep=$/;
    $/='\0xFF';
    open F, "$f" || die "Can not open file $f";
    $hf=<F>;
    close F;

    $hf=~ s/\s*#include <libgnome\/libgnome.h>//;

    open F, ">$f" || die "Can not open file $f for writing";
    print F $hf;
    close F;

    $/=$old_sep;
}

undef @files;
undef $f;

@files=`egrep -li '[^N]_\\(""\\)' *_glade.cc`;

foreach $f ( @files ) {

    chop($f);

    print " 4 '$f'\n";

    $old_sep=$/;
    $/='\0xFF';
    open F, "$f" || die "Can not open file $f";
    $hf=<F>;
    close F;

    $hf=~ s/([^N])_\(""\)/\1N_("")/g;

    open F, ">$f" || die "Can not open file $f for writing";
    print F $hf;
    close F;

    $/=$old_sep;
}


# @files=`ls *_glade.cc *_glade.hh`;
#
#foreach $f ( @files ) {
#    chop($f);
#    `diff -q -N -I\"^// generated\" -I\"^// glade--.*\.glade$\"  .. $f >/dev/null 2>1`;
#    $res=$?;
#    if ($res!=0) {
#	`cp $f ..`
#    }
#}


($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst) = localtime(time);

open F, "> postglade.timestamp" || die "Could  not create file postglade.timestamp";
printf F "%02d:%02d:%02d %02d-%02d-%04d",$hour,$min,$sec,$mon+1,$mday,$year+1900;
close F;

# `touch postglade.timestamp`
